AddedImport class final

An import that the pipeline added to a file of the app for a fragment, with who contributed the fragment.

Constructors

AddedImport(ImportRef import, ContributionOrigin contributor)
Creates the record of import, needed by contributor.
const

Properties

contributor → ContributionOrigin
Who contributed the fragment that needs it.
final
hashCode → int
The hash code for this object.
no setterinherited
import → ImportRef
The import, as the fragment gave it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited