roleOptions property

Map<String, String?> roleOptions
final

Values of role options by name, as --start /home on the command line, for the choices of the roles when the app of the case is rendered.

Implementation

final Map<String, String?> roleOptions;