ContractHarness constructor

ContractHarness(
  1. ModuleRegistry registry, {
  2. ModuleContext context = defaultContext,
  3. bool render = true,
  4. Map<String, String?> roleOptions = const {},
})

Creates the harness for registry, generating apps described by context, and rendering them unless render is false, with the roleOptions of every case.

Implementation

ContractHarness(
  this.registry, {
  this.context = defaultContext,
  this.render = true,
  this.roleOptions = const {},
});