checkAll method

Future<List<ContractResult>> checkAll()

Checks every case of every module and every role of the registry, and returns the results of the cases whose app no case before built.

Implementation

Future<List<ContractResult>> checkAll() async {
  final results = <ContractResult>[];
  final apps = <String>{};
  for (final contractCase in [
    for (final module in registry.modules)
      ...casesOfModule(module.descriptor.id),
    for (final role in registry.roles) ...casesOfRole(role),
  ]) {
    final result = await check(contractCase);
    final key = result.appKey;
    if (key == null || apps.add(key)) results.add(result);
  }
  return results;
}