render property
Whether the harness renders the app of every case that has no errors and checks the rendered code.
Implementation
final bool render;
Whether the harness renders the app of every case that has no errors and checks the rendered code.
final bool render;