roleOptions property

Map<String, String?> roleOptions
final

Values of role options by name for every case; the options of a case override them.

A question of a role that no option answers gets the answer of a user who presses Enter; see ContractResult.answers.

Implementation

final Map<String, String?> roleOptions;