app property
The rendered app, if the harness rendered it: when it renders apps and the stages before found no error.
Implementation
final RenderedApp? app;
The rendered app, if the harness rendered it: when it renders apps and the stages before found no error.
final RenderedApp? app;