appKey property

String? get appKey

The modules of the app with their variants, which tell apart the apps of different cases, or null if the case did not resolve.

Implementation

String? get appKey => switch (resolution) {
      null => null,
      final resolution => ([
          for (final module in resolution.modules)
            '${module.id}(${module.variant ?? ''})',
        ]..sort())
            .join(','),
    };