cycle property

List<String> cycle
final

The modules and templates on a cycle of edges through contributors, including those that do not contribute, or empty if there is none. The contributors on a cycle are ordered by name among themselves.

Implementation

final List<String> cycle;