DependencyOf class final
Another module depends on the module.
- Inheritance
-
- Object
- SelectionReason
- DependencyOf
Constructors
- DependencyOf(ModuleId dependent)
-
Creates the reason:
dependentdepends on the module.const
Properties
- dependent → ModuleId
-
The module that depends on it.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited