constraintText property

String? constraintText
final

constraint as a contribution wrote it, such as ^9.1.0, when the intersection is one of the contributed constraints; otherwise as pub_semver prints it, such as >=9.2.0 <10.0.0.

Implementation

final String? constraintText;