alternatives property
The other providers a run would offer, if --explain took the first
one instead of asking.
Implementation
final List<ModuleId> alternatives;
The other providers a run would offer, if --explain took the first
one instead of asking.
final List<ModuleId> alternatives;