requiredBy property
Who needs the role, and how, as the start of a phrase such as
home requires or every app needs.
Implementation
final String requiredBy;
Who needs the role, and how, as the start of a phrase such as
home requires or every app needs.
final String requiredBy;