RenderedApp class final

The app that stage 8 rendered, in memory.

Constructors

RenderedApp(Iterable<RenderedFile> files)
Creates the app of files.

Properties

files → Map<String, RenderedFile>
The files by path, relative to the root of the app, sorted by path.
final
hashCode → int
The hash code for this object.
no setterinherited
owners → Map<String, ContributionOrigin>
Who generated each file, by path.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texts → Map<String, String>
The text of every text file, by path.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited