Resolution class final

Stage 3 of the pipeline: the modules of the app and the roles they provide.

Constructors

Resolution(List<ResolvedModule> modules)
Creates the resolution.

Properties

hashCode → int
The hash code for this object.
no setterinherited
modules → List<ResolvedModule>
The modules of the app, in the order they were selected: the requested ones in the order given, then those added for them.
final
presentRoles → Set<Role<Object>>
The roles present in the app: those its modules provide, in the order of their first provider.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependencyClosure(ModuleId id) → Set<ModuleId>
The modules id depends on, directly or not, or none if id is not in the app.
module(ModuleId id) → ResolvedModule?
The module id, if it is in the app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
providersOf(Role<Object> role) → List<ResolvedModule>
The modules of the app that provide role.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

providerObject(ResolvedModule module, Role<Object> role) → RoleProvider<Object>
The provider object of role of the module module.