ResolvedModule class final

A module of the app, with why it is there and which of its variants applies.

Constructors

ResolvedModule(SmfModule module, SelectionReason reason, {ModuleId? variant})
Creates the module.
const

Properties

descriptor → ModuleDescriptor
The descriptor of the module.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → ModuleId
The id of the module.
no setter
module → SmfModule
The module.
final
origin → ModuleOrigin
The origin of the module's own contributions.
no setter
reason → SelectionReason
Why the module is in the app.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variant → ModuleId?
The provider whose variant of the module applies, if the module has variants.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited