TemplateScan class final

What scanTemplate found in a template file.

Constructors

TemplateScan(List<TemplateTag> tags, {List<TemplateSection> sections = const [], List<int> partialLines = const [], int? delimiterLine})
Creates the result of a scan.
const

Properties

delimiterLine → int?
The line of a {{=… …=}} tag that changes the delimiters, after which the scan stops, or null if the file has none.
final
hashCode → int
The hash code for this object.
no setterinherited
partialLines → List<int>
The lines of the partials the file includes, {{> name}}.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sections → List<TemplateSection>
The sections, in the order they open.
final
tags → List<TemplateTag>
The variables, in the order of the file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited