delimiterLine property

int? delimiterLine
final

The line of a {{=… …=}} tag that changes the delimiters, after which the scan stops, or null if the file has none.

Implementation

final int? delimiterLine;