TemplateSection class final
A mustache section in a template file, {{#name}} or {{^name}}, as
the scan found it.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inverted → bool
-
Whether it is an inverted section,
{{^name}}.final - line → int
-
The line where the section opens, from 1.
final
- name → String
-
The name of the section, such as
has_router.final - path → String
-
The path of the template file in its brick.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
String> -
The names of the sections this one is in, outermost first.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited