afterBrace property
Whether a { comes right before the variable, which mustache reads as
part of the variable's braces.
Implementation
final bool afterBrace;
Whether a { comes right before the variable, which mustache reads as
part of the variable's braces.
final bool afterBrace;