isSocketTag property
bool
get
isSocketTag
Whether the name is meant as the tag of a socket: it starts with
smf.
Implementation
bool get isSocketTag => name.startsWith('smf');
Whether the name is meant as the tag of a socket: it starts with
smf.
bool get isSocketTag => name.startsWith('smf');