triple property

bool triple
final

Whether the variable has three braces, which mustache does not escape. {{& name}}, which mustache does not escape either, counts as two.

Implementation

final bool triple;