ValidationResult class final

What stage 5 found and computed.

Constructors

ValidationResult({required List<SmfIssue> issues, required Map<SocketRef<SocketKind>, ContributionOrder> socketOrders, required ContributionOrder postGenOrder, required MergedPubspec pubspec})
Creates the result.
const

Properties

hasErrors → bool
Whether generation cannot continue.
no setter
hashCode → int
The hash code for this object.
no setterinherited
issues → List<SmfIssue>
The errors and warnings found.
final
postGenOrder → ContributionOrder
The post-generation steps that apply, in the order they run.
final
pubspec → MergedPubspec
The merged pubspec.yaml.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketOrders → Map<SocketRef<SocketKind>, ContributionOrder>
The contributions of each socket that apply, in their final order.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited