socketOrders property
The contributions of each socket that apply, in their final order.
Implementation
final Map<SocketRef, ContributionOrder> socketOrders;
The contributions of each socket that apply, in their final order.
final Map<SocketRef, ContributionOrder> socketOrders;