Collected class final
A contribution with who made it and whether it applies in the app.
Constructors
Properties
- applies → bool
-
Whether it applies: every role in its
Contribution.whenis present and, forRoleDataand for aSocketContributionto a socket of a role, that role is.final - contribution → Contribution
-
The contribution; a
RoleDataorSocketContributioncarries origin too.final - hashCode → int
-
The hash code for this object.
no setterinherited
- origin → ContributionOrigin
-
Who contributed it.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited