ContractHarness constructor
ContractHarness(
- ModuleRegistry registry, {
- ModuleContext context = defaultContext,
- bool render = true,
- Map<
String, String?> roleOptions = const {},
Creates the harness for registry, generating apps described by
context, and rendering them unless render is false, with the
roleOptions of every case.
Implementation
ContractHarness(
this.registry, {
this.context = defaultContext,
this.render = true,
this.roleOptions = const {},
});