ContractResult class final
What the harness found in one ContractCase.
Constructors
-
ContractResult(ContractCase contractCase, List<
SmfIssue> issues, {Resolution? resolution, Collection? collection, ValidationResult? validation, Map<Role< ? choices, Map<Object> , Object?>String, String> answers = const {}, RenderedApp? app}) -
Creates the result.
const
Properties
-
answers
→ Map<
String, String> -
The values of role options by name that make the choices of the roles
whose questions the harness answered, as a user who presses Enter,
without asking, such as
--startfor the first of several screens that can start the app; seeRoleTemplate.optionsOf.final - app → RenderedApp?
-
The rendered app, if the harness rendered it: when it renders apps and
the stages before found no error.
final
- appKey → String?
-
The modules of the app with their variants, which tell apart the apps
of different cases, or
nullif the case did not resolve.no setter -
choices
→ Map<
Role< ?Object> , Object?> -
The results of the roles' choices, if the harness rendered the app.
final
- collection → Collection?
-
The contributions of the app, if the case resolved.
final
- contractCase → ContractCase
-
The case.
final
-
errors
→ List<
SmfIssue> -
The errors among issues.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
→ List<
SmfIssue> -
The errors and warnings found.
final
- resolution → Resolution?
-
The modules of the app, if the case resolved.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validation → ValidationResult?
-
The result of stage 5, with the order of every socket and the merged
pubspec, if the case resolved.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited