answers property
The values of role options by name that make the choices of the roles
whose questions the harness answered, as a user who presses Enter,
without asking, such as --start for the first of several screens
that can start the app; see RoleTemplate.optionsOf.
With the options of the case, they make a run without a terminal generate the app that the harness rendered: the harness makes the choices again without a terminal with them, and a role whose answer they do not reproduce is an error of the case.
Implementation
final Map<String, String> answers;