ContributionOrder class final
The contributions of a socket, or the post-generation steps, in the order they render or run.
Constructors
Properties
-
contributions
→ List<
Collected> -
The contributions in their final order.
final
-
cycle
→ List<
String> -
The modules and templates on a cycle of edges through contributors,
including those that do not contribute, or empty if there is none.
The contributors on a cycle are ordered by name among themselves.
final
-
edges
→ List<
OrderEdge> -
The edges between the contributors, after mutual edges cancelled out.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited