MergedDependency class final
A dependency of the merged pubspec.
Constructors
-
MergedDependency(String package, {required PubspecSource source, required List<
ContributionOrigin> origins, VersionConstraint? constraint, String? constraintText, String? sdk}) -
Creates the dependency on
package.const
Properties
- constraint → VersionConstraint?
-
The intersection of the constraints of a hosted package.
final
- constraintText → String?
-
constraint as a contribution wrote it, such as
^9.1.0, when the intersection is one of the contributed constraints; otherwise aspub_semverprints it, such as>=9.2.0 <10.0.0.final - hashCode → int
-
The hash code for this object.
no setterinherited
-
origins
→ List<
ContributionOrigin> -
Who contributed it.
final
- package → String
-
The name of the package.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdk → String?
-
The SDK of an SDK package.
final
- source → PubspecSource
-
Where the package comes from.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited