dependencies property
The packages besides smf_contracts that the code of the module uses,
such as mason for the bundles of its bricks, or the package of a
module it depends on, which the tests use too.
Implementation
final Set<String> dependencies;