testModules property
The packages of other modules that the tests use, besides
smf_pipeline, such as smf_flutter_core for the app entry of the
apps they render.
pub.dev resolves the dev dependencies of a package when it analyzes it, so they must not form a cycle: the tests of a package that another module tests with do not use that module in turn.
Implementation
final Set<String> testModules;