An edge of the order of contributors: before comes before after.
Properties
-
after
→ String
-
The contributor that comes after it, such as
role:analytics.
final
-
before
→ String
-
The contributor that comes first, such as
firebase_core.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
reason
→ String
-
Why, as a phrase such as
firebase_analytics depends on firebase_core.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
override