ProviderOf class final
The module provides a role the app needs.
- Inheritance
-
- Object
- SelectionReason
- ProviderOf
Constructors
-
ProviderOf(Role<
Object> role, String requiredBy, {bool chosen = false, List<ModuleId> alternatives = const []}) -
Creates the reason: the module provides
role, whichrequiredByneeds.const
Properties
-
alternatives
→ List<
ModuleId> -
The other providers a run would offer, if
--explaintook the first one instead of asking.final - chosen → bool
-
Whether the user chose the module among several providers.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requiredBy → String
-
Who needs the role, and how, as the start of a phrase such as
home requiresorevery app needs.final -
role
→ Role<
Object> -
The role the module provides.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited