modules property
The modules of the app, in the order they were selected: the requested ones in the order given, then those added for them.
Implementation
final List<ResolvedModule> modules;
The modules of the app, in the order they were selected: the requested ones in the order given, then those added for them.
final List<ResolvedModule> modules;