triple property
Whether the variable has three braces, which mustache does not escape.
{{& name}}, which mustache does not escape either, counts as two.
Implementation
final bool triple;
Whether the variable has three braces, which mustache does not escape.
{{& name}}, which mustache does not escape either, counts as two.
final bool triple;